@@ -1,60 +1,72 @@
 import {
+  DataQuery,
+  DataSourceApi,
+  dateTime,
+  ExploreMode,
+  LoadingState,
+  LogsDedupStrategy,
+  RawTimeRange,
+  toDataFrame,
+  UrlQueryMap,
+  ExploreUrlState,
+} from '@grafana/data';
+
+import {
+  createEmptyQueryResponse,
+  exploreReducer,
+  initialExploreState,
   itemReducer,
   makeExploreItemState,
-  exploreReducer,
   makeInitialUpdateState,
-  initialExploreState,
-  createEmptyQueryResponse,
 } from './reducers';
-import { ExploreId, ExploreItemState, ExploreUrlState, ExploreState, ExploreMode } from 'app/types/explore';
+import { ExploreId, ExploreItemState, ExploreState } from 'app/types/explore';
 import { reducerTester } from 'test/core/redux/reducerTester';
 import {
-  scanStartAction,
-  updateDatasourceInstanceAction,
-  splitOpenAction,
-  splitCloseAction,
-  changeModeAction,
-  scanStopAction,
-  toggleGraphAction,
-  toggleTableAction,
   changeRangeAction,
   changeRefreshIntervalAction,
+  scanStartAction,
+  scanStopAction,
+  splitCloseAction,
+  splitOpenAction,
+  toggleGraphAction,
+  toggleTableAction,
+  updateDatasourceInstanceAction,
+  addQueryRowAction,
+  removeQueryRowAction,
 } from './actionTypes';
-import { Reducer } from 'redux';
-import { ActionOf } from 'app/core/redux/actionCreatorFactory';
-import { updateLocation } from 'app/core/actions/location';
-import { serializeStateToUrlParam } from 'app/core/utils/explore';
-import TableModel from 'app/core/table_model';
-import { DataSourceApi, DataQuery, LogsDedupStrategy, dateTime, LoadingState } from '@grafana/data';
+import { updateLocation } from '../../../core/actions';
+import { serializeStateToUrlParam } from '@grafana/data/src/utils/url';
+
+const QUERY_KEY_REGEX = /Q-(?:[a-z0-9]+-){5}(?:[0-9]+)/;
 
 describe('Explore item reducer', () => {
   describe('scanning', () => {
     it('should start scanning', () => {
-      const initalState = {
+      const initialState = {
         ...makeExploreItemState(),
         scanning: false,
       };
 
-      reducerTester()
-        .givenReducer(itemReducer as Reducer<ExploreItemState, ActionOf<any>>, initalState)
+      reducerTester<ExploreItemState>()
+        .givenReducer(itemReducer, initialState)
         .whenActionIsDispatched(scanStartAction({ exploreId: ExploreId.left }))
         .thenStateShouldEqual({
-          ...initalState,
+          ...makeExploreItemState(),
           scanning: true,
         });
     });
     it('should stop scanning', () => {
-      const initalState = {
+      const initialState = {
         ...makeExploreItemState(),
         scanning: true,
-        scanRange: {},
+        scanRange: {} as RawTimeRange,
       };
 
-      reducerTester()
-        .givenReducer(itemReducer as Reducer<ExploreItemState, ActionOf<any>>, initalState)
+      reducerTester<ExploreItemState>()
+        .givenReducer(itemReducer, initialState)
         .whenActionIsDispatched(scanStopAction({ exploreId: ExploreId.left }))
         .thenStateShouldEqual({
-          ...initalState,
+          ...makeExploreItemState(),
           scanning: false,
           scanRange: undefined,
         });
@@ -62,17 +74,6 @@ describe('Explore item reducer', () => {
   });
 
   describe('changing datasource', () => {
-    describe('when changeDataType is dispatched', () => {
-      it('then it should set correct state', () => {
-        reducerTester()
-          .givenReducer(itemReducer, {})
-          .whenActionIsDispatched(changeModeAction({ exploreId: ExploreId.left, mode: ExploreMode.Logs }))
-          .thenStateShouldEqual({
-            mode: ExploreMode.Logs,
-          });
-      });
-    });
-
     describe('when updateDatasourceInstanceAction is dispatched', () => {
       describe('and datasourceInstance supports graph, logs, table and has a startpage', () => {
         it('then it should set correct state', () => {
@@ -88,31 +89,26 @@ describe('Explore item reducer', () => {
           } as DataSourceApi;
           const queries: DataQuery[] = [];
           const queryKeys: string[] = [];
-          const initalState: Partial<ExploreItemState> = {
+          const initialState: ExploreItemState = ({
             datasourceInstance: null,
-            StartPage: null,
-            showingStartPage: false,
             queries,
             queryKeys,
-          };
+          } as unknown) as ExploreItemState;
           const expectedState: any = {
             datasourceInstance,
-            StartPage,
-            showingStartPage: true,
             queries,
             queryKeys,
             graphResult: null,
             logsResult: null,
             tableResult: null,
             supportedModes: [ExploreMode.Metrics, ExploreMode.Logs],
-            mode: ExploreMode.Metrics,
             latency: 0,
             loading: false,
             queryResponse: createEmptyQueryResponse(),
           };
 
-          reducerTester()
-            .givenReducer(itemReducer, initalState)
+          reducerTester<ExploreItemState>()
+            .givenReducer(itemReducer, initialState)
             .whenActionIsDispatched(updateDatasourceInstanceAction({ exploreId: ExploreId.left, datasourceInstance }))
             .thenStateShouldEqual(expectedState);
         });
@@ -122,7 +118,7 @@ describe('Explore item reducer', () => {
 
   describe('changing refresh intervals', () => {
     it("should result in 'streaming' state, when live-tailing is active", () => {
-      const initalState = makeExploreItemState();
+      const initialState = makeExploreItemState();
       const expectedState = {
         ...makeExploreItemState(),
         refreshInterval: 'LIVE',
@@ -137,14 +133,14 @@ describe('Explore item reducer', () => {
           state: LoadingState.Streaming,
         },
       };
-      reducerTester()
-        .givenReducer(itemReducer, initalState)
+      reducerTester<ExploreItemState>()
+        .givenReducer(itemReducer, initialState)
         .whenActionIsDispatched(changeRefreshIntervalAction({ exploreId: ExploreId.left, refreshInterval: 'LIVE' }))
         .thenStateShouldEqual(expectedState);
     });
 
     it("should result in 'done' state, when live-tailing is stopped", () => {
-      const initalState = makeExploreItemState();
+      const initialState = makeExploreItemState();
       const expectedState = {
         ...makeExploreItemState(),
         refreshInterval: '',
@@ -157,8 +153,8 @@ describe('Explore item reducer', () => {
           state: LoadingState.Done,
         },
       };
-      reducerTester()
-        .givenReducer(itemReducer, initalState)
+      reducerTester<ExploreItemState>()
+        .givenReducer(itemReducer, initialState)
         .whenActionIsDispatched(changeRefreshIntervalAction({ exploreId: ExploreId.left, refreshInterval: '' }))
         .thenStateShouldEqual(expectedState);
     });
@@ -167,23 +163,34 @@ describe('Explore item reducer', () => {
   describe('toggling panels', () => {
     describe('when toggleGraphAction is dispatched', () => {
       it('then it should set correct state', () => {
-        reducerTester()
-          .givenReducer(itemReducer, { graphResult: [] })
+        reducerTester<ExploreItemState>()
+          .givenReducer(itemReducer, ({ graphResult: [] } as unknown) as ExploreItemState)
           .whenActionIsDispatched(toggleGraphAction({ exploreId: ExploreId.left }))
-          .thenStateShouldEqual({ showingGraph: true, graphResult: [] })
+          .thenStateShouldEqual(({ showingGraph: true, graphResult: [] } as unknown) as ExploreItemState)
           .whenActionIsDispatched(toggleGraphAction({ exploreId: ExploreId.left }))
-          .thenStateShouldEqual({ showingGraph: false, graphResult: null });
+          .thenStateShouldEqual(({ showingGraph: false, graphResult: [] } as unknown) as ExploreItemState);
       });
     });
 
     describe('when toggleTableAction is dispatched', () => {
       it('then it should set correct state', () => {
-        reducerTester()
-          .givenReducer(itemReducer, { tableResult: {} })
+        const table = toDataFrame({
+          name: 'logs',
+          fields: [
+            {
+              name: 'time',
+              type: 'number',
+              values: [1, 2],
+            },
+          ],
+        });
+
+        reducerTester<ExploreItemState>()
+          .givenReducer(itemReducer, ({ tableResult: table } as unknown) as ExploreItemState)
           .whenActionIsDispatched(toggleTableAction({ exploreId: ExploreId.left }))
-          .thenStateShouldEqual({ showingTable: true, tableResult: {} })
+          .thenStateShouldEqual(({ showingTable: true, tableResult: table } as unknown) as ExploreItemState)
           .whenActionIsDispatched(toggleTableAction({ exploreId: ExploreId.left }))
-          .thenStateShouldEqual({ showingTable: false, tableResult: new TableModel() });
+          .thenStateShouldEqual(({ showingTable: false, tableResult: table } as unknown) as ExploreItemState);
       });
     });
   });
@@ -191,12 +198,12 @@ describe('Explore item reducer', () => {
   describe('changing range', () => {
     describe('when changeRangeAction is dispatched', () => {
       it('then it should set correct state', () => {
-        reducerTester()
-          .givenReducer(itemReducer, {
+        reducerTester<ExploreItemState>()
+          .givenReducer(itemReducer, ({
             update: { ...makeInitialUpdateState(), range: true },
             range: null,
             absoluteRange: null,
-          })
+          } as unknown) as ExploreItemState)
           .whenActionIsDispatched(
             changeRangeAction({
               exploreId: ExploreId.left,
@@ -204,14 +211,83 @@ describe('Explore item reducer', () => {
               range: { from: dateTime('2019-01-01'), to: dateTime('2019-01-02'), raw: { from: 'now-1d', to: 'now' } },
             })
           )
-          .thenStateShouldEqual({
+          .thenStateShouldEqual(({
             update: { ...makeInitialUpdateState(), range: false },
             absoluteRange: { from: 1546297200000, to: 1546383600000 },
             range: { from: dateTime('2019-01-01'), to: dateTime('2019-01-02'), raw: { from: 'now-1d', to: 'now' } },
-          });
+          } as unknown) as ExploreItemState);
       });
     });
   });
+
+  describe('query rows', () => {
+    it('adds a new query row', () => {
+      reducerTester<ExploreItemState>()
+        .givenReducer(itemReducer, ({
+          queries: [],
+        } as unknown) as ExploreItemState)
+        .whenActionIsDispatched(
+          addQueryRowAction({
+            exploreId: ExploreId.left,
+            query: { refId: 'A', key: 'mockKey' },
+            index: 0,
+          })
+        )
+        .thenStateShouldEqual(({
+          queries: [{ refId: 'A', key: 'mockKey' }],
+          queryKeys: ['mockKey-0'],
+        } as unknown) as ExploreItemState);
+    });
+    it('removes a query row', () => {
+      reducerTester<ExploreItemState>()
+        .givenReducer(itemReducer, ({
+          queries: [
+            { refId: 'A', key: 'mockKey' },
+            { refId: 'B', key: 'mockKey' },
+          ],
+          queryKeys: ['mockKey-0', 'mockKey-1'],
+        } as unknown) as ExploreItemState)
+        .whenActionIsDispatched(
+          removeQueryRowAction({
+            exploreId: ExploreId.left,
+            index: 0,
+          })
+        )
+        .thenStatePredicateShouldEqual((resultingState: ExploreItemState) => {
+          expect(resultingState.queries.length).toBe(1);
+          expect(resultingState.queries[0].refId).toBe('A');
+          expect(resultingState.queries[0].key).toMatch(QUERY_KEY_REGEX);
+          expect(resultingState.queryKeys[0]).toMatch(QUERY_KEY_REGEX);
+          return true;
+        });
+    });
+    it('reassigns query refId after removing a query to keep queries in order', () => {
+      reducerTester<ExploreItemState>()
+        .givenReducer(itemReducer, ({
+          queries: [{ refId: 'A' }, { refId: 'B' }, { refId: 'C' }],
+          queryKeys: ['undefined-0', 'undefined-1', 'undefined-2'],
+        } as unknown) as ExploreItemState)
+        .whenActionIsDispatched(
+          removeQueryRowAction({
+            exploreId: ExploreId.left,
+            index: 0,
+          })
+        )
+        .thenStatePredicateShouldEqual((resultingState: ExploreItemState) => {
+          expect(resultingState.queries.length).toBe(2);
+          const queriesRefIds = resultingState.queries.map(query => query.refId);
+          const queriesKeys = resultingState.queries.map(query => query.key);
+          expect(queriesRefIds).toEqual(['A', 'B']);
+          queriesKeys.forEach(queryKey => {
+            expect(queryKey).toMatch(QUERY_KEY_REGEX);
+          });
+          resultingState.queryKeys.forEach(queryKey => {
+            expect(queryKey).toMatch(QUERY_KEY_REGEX);
+          });
+          return true;
+        });
+    });
+  });
 });
 
 export const setup = (urlStateOverrides?: any) => {
@@ -223,7 +299,6 @@ export const setup = (urlStateOverrides?: any) => {
       from: '',
       to: '',
     },
-    mode: ExploreMode.Metrics,
     ui: {
       dedupStrategy: LogsDedupStrategy.none,
       showingGraph: false,
@@ -233,10 +308,14 @@ export const setup = (urlStateOverrides?: any) => {
   };
   const urlState: ExploreUrlState = { ...urlStateDefaults, ...urlStateOverrides };
   const serializedUrlState = serializeStateToUrlParam(urlState);
-  const initalState = { split: false, left: { urlState, update }, right: { urlState, update } };
+  const initialState = ({
+    split: false,
+    left: { urlState, update },
+    right: { urlState, update },
+  } as unknown) as ExploreState;
 
   return {
-    initalState,
+    initialState,
     serializedUrlState,
   };
 };
@@ -244,76 +323,76 @@ export const setup = (urlStateOverrides?: any) => {
 describe('Explore reducer', () => {
   describe('split view', () => {
     it("should make right pane a duplicate of the given item's state on split open", () => {
-      const leftItemMock = {
+      const leftItemMock = ({
         containerWidth: 100,
-      } as ExploreItemState;
+      } as unknown) as ExploreItemState;
 
-      const initalState = {
+      const initialState = ({
         split: null,
         left: leftItemMock as ExploreItemState,
         right: makeExploreItemState(),
-      } as ExploreState;
+      } as unknown) as ExploreState;
 
-      reducerTester()
-        .givenReducer(exploreReducer as Reducer<ExploreState, ActionOf<any>>, initalState)
+      reducerTester<ExploreState>()
+        .givenReducer(exploreReducer, initialState)
         .whenActionIsDispatched(splitOpenAction({ itemState: leftItemMock }))
-        .thenStateShouldEqual({
+        .thenStateShouldEqual(({
           split: true,
           left: leftItemMock,
           right: leftItemMock,
-        });
+        } as unknown) as ExploreState);
     });
 
     describe('split close', () => {
       it('should keep right pane as left when left is closed', () => {
-        const leftItemMock = {
+        const leftItemMock = ({
           containerWidth: 100,
-        } as ExploreItemState;
+        } as unknown) as ExploreItemState;
 
-        const rightItemMock = {
+        const rightItemMock = ({
           containerWidth: 200,
-        } as ExploreItemState;
+        } as unknown) as ExploreItemState;
 
-        const initalState = {
+        const initialState = ({
           split: null,
           left: leftItemMock,
           right: rightItemMock,
-        } as ExploreState;
+        } as unknown) as ExploreState;
 
         // closing left item
-        reducerTester()
-          .givenReducer(exploreReducer as Reducer<ExploreState, ActionOf<any>>, initalState)
+        reducerTester<ExploreState>()
+          .givenReducer(exploreReducer, initialState)
           .whenActionIsDispatched(splitCloseAction({ itemId: ExploreId.left }))
-          .thenStateShouldEqual({
+          .thenStateShouldEqual(({
             split: false,
             left: rightItemMock,
             right: initialExploreState.right,
-          });
+          } as unknown) as ExploreState);
       });
       it('should reset right pane when it is closed ', () => {
-        const leftItemMock = {
+        const leftItemMock = ({
           containerWidth: 100,
-        } as ExploreItemState;
+        } as unknown) as ExploreItemState;
 
-        const rightItemMock = {
+        const rightItemMock = ({
           containerWidth: 200,
-        } as ExploreItemState;
+        } as unknown) as ExploreItemState;
 
-        const initalState = {
+        const initialState = ({
           split: null,
           left: leftItemMock,
           right: rightItemMock,
-        } as ExploreState;
+        } as unknown) as ExploreState;
 
         // closing left item
-        reducerTester()
-          .givenReducer(exploreReducer as Reducer<ExploreState, ActionOf<any>>, initalState)
+        reducerTester<ExploreState>()
+          .givenReducer(exploreReducer, initialState)
           .whenActionIsDispatched(splitCloseAction({ itemId: ExploreId.right }))
-          .thenStateShouldEqual({
+          .thenStateShouldEqual(({
             split: false,
             left: leftItemMock,
             right: initialExploreState.right,
-          });
+          } as unknown) as ExploreState);
       });
     });
   });
@@ -321,30 +400,30 @@ describe('Explore reducer', () => {
   describe('when updateLocation is dispatched', () => {
     describe('and payload does not contain a query', () => {
       it('then it should just return state', () => {
-        reducerTester()
-          .givenReducer(exploreReducer, {})
-          .whenActionIsDispatched(updateLocation({ query: null }))
-          .thenStateShouldEqual({});
+        reducerTester<ExploreState>()
+          .givenReducer(exploreReducer, ({} as unknown) as ExploreState)
+          .whenActionIsDispatched(updateLocation({ query: (null as unknown) as UrlQueryMap }))
+          .thenStateShouldEqual(({} as unknown) as ExploreState);
       });
     });
 
     describe('and payload contains a query', () => {
       describe("but does not contain 'left'", () => {
         it('then it should just return state', () => {
-          reducerTester()
-            .givenReducer(exploreReducer, {})
+          reducerTester<ExploreState>()
+            .givenReducer(exploreReducer, ({} as unknown) as ExploreState)
             .whenActionIsDispatched(updateLocation({ query: {} }))
-            .thenStateShouldEqual({});
+            .thenStateShouldEqual(({} as unknown) as ExploreState);
         });
       });
 
       describe("and query contains a 'right'", () => {
         it('then it should add split in state', () => {
-          const { initalState, serializedUrlState } = setup();
-          const expectedState = { ...initalState, split: true };
+          const { initialState, serializedUrlState } = setup();
+          const expectedState = { ...initialState, split: true };
 
-          reducerTester()
-            .givenReducer(exploreReducer, initalState)
+          reducerTester<ExploreState>()
+            .givenReducer(exploreReducer, initialState)
             .whenActionIsDispatched(
               updateLocation({
                 query: {
@@ -360,12 +439,12 @@ describe('Explore reducer', () => {
       describe("and query contains a 'left'", () => {
         describe('but urlState is not set in state', () => {
           it('then it should just add urlState and update in state', () => {
-            const { initalState, serializedUrlState } = setup();
-            const urlState: ExploreUrlState = null;
-            const stateWithoutUrlState = { ...initalState, left: { urlState } };
-            const expectedState = { ...initalState };
+            const { initialState, serializedUrlState } = setup();
+            const urlState: ExploreUrlState = (null as unknown) as ExploreUrlState;
+            const stateWithoutUrlState = ({ ...initialState, left: { urlState } } as unknown) as ExploreState;
+            const expectedState = { ...initialState };
 
-            reducerTester()
+            reducerTester<ExploreState>()
               .givenReducer(exploreReducer, stateWithoutUrlState)
               .whenActionIsDispatched(
                 updateLocation({
@@ -381,11 +460,11 @@ describe('Explore reducer', () => {
 
         describe("but '/explore' is missing in path", () => {
           it('then it should just add urlState and update in state', () => {
-            const { initalState, serializedUrlState } = setup();
-            const expectedState = { ...initalState };
+            const { initialState, serializedUrlState } = setup();
+            const expectedState = { ...initialState };
 
-            reducerTester()
-              .givenReducer(exploreReducer, initalState)
+            reducerTester<ExploreState>()
+              .givenReducer(exploreReducer, initialState)
               .whenActionIsDispatched(
                 updateLocation({
                   query: {
@@ -401,29 +480,29 @@ describe('Explore reducer', () => {
         describe("and '/explore' is in path", () => {
           describe('and datasource differs', () => {
             it('then it should return update datasource', () => {
-              const { initalState, serializedUrlState } = setup();
+              const { initialState, serializedUrlState } = setup();
               const expectedState = {
-                ...initalState,
+                ...initialState,
                 left: {
-                  ...initalState.left,
+                  ...initialState.left,
                   update: {
-                    ...initalState.left.update,
+                    ...initialState.left.update,
                     datasource: true,
                   },
                 },
               };
-              const stateWithDifferentDataSource = {
-                ...initalState,
+              const stateWithDifferentDataSource: any = {
+                ...initialState,
                 left: {
-                  ...initalState.left,
+                  ...initialState.left,
                   urlState: {
-                    ...initalState.left.urlState,
+                    ...initialState.left.urlState,
                     datasource: 'different datasource',
                   },
                 },
               };
 
-              reducerTester()
+              reducerTester<ExploreState>()
                 .givenReducer(exploreReducer, stateWithDifferentDataSource)
                 .whenActionIsDispatched(
                   updateLocation({
@@ -439,23 +518,23 @@ describe('Explore reducer', () => {
 
           describe('and range differs', () => {
             it('then it should return update range', () => {
-              const { initalState, serializedUrlState } = setup();
+              const { initialState, serializedUrlState } = setup();
               const expectedState = {
-                ...initalState,
+                ...initialState,
                 left: {
-                  ...initalState.left,
+                  ...initialState.left,
                   update: {
-                    ...initalState.left.update,
+                    ...initialState.left.update,
                     range: true,
                   },
                 },
               };
-              const stateWithDifferentDataSource = {
-                ...initalState,
+              const stateWithDifferentDataSource: any = {
+                ...initialState,
                 left: {
-                  ...initalState.left,
+                  ...initialState.left,
                   urlState: {
-                    ...initalState.left.urlState,
+                    ...initialState.left.urlState,
                     range: {
                       from: 'now',
                       to: 'now-6h',
@@ -464,7 +543,7 @@ describe('Explore reducer', () => {
                 },
               };
 
-              reducerTester()
+              reducerTester<ExploreState>()
                 .givenReducer(exploreReducer, stateWithDifferentDataSource)
                 .whenActionIsDispatched(
                   updateLocation({
@@ -480,29 +559,29 @@ describe('Explore reducer', () => {
 
           describe('and queries differs', () => {
             it('then it should return update queries', () => {
-              const { initalState, serializedUrlState } = setup();
+              const { initialState, serializedUrlState } = setup();
               const expectedState = {
-                ...initalState,
+                ...initialState,
                 left: {
-                  ...initalState.left,
+                  ...initialState.left,
                   update: {
-                    ...initalState.left.update,
+                    ...initialState.left.update,
                     queries: true,
                   },
                 },
               };
-              const stateWithDifferentDataSource = {
-                ...initalState,
+              const stateWithDifferentDataSource: any = {
+                ...initialState,
                 left: {
-                  ...initalState.left,
+                  ...initialState.left,
                   urlState: {
-                    ...initalState.left.urlState,
+                    ...initialState.left.urlState,
                     queries: [{ expr: '{__filename__="some.log"}' }],
                   },
                 },
               };
 
-              reducerTester()
+              reducerTester<ExploreState>()
                 .givenReducer(exploreReducer, stateWithDifferentDataSource)
                 .whenActionIsDispatched(
                   updateLocation({
@@ -518,32 +597,32 @@ describe('Explore reducer', () => {
 
           describe('and ui differs', () => {
             it('then it should return update ui', () => {
-              const { initalState, serializedUrlState } = setup();
+              const { initialState, serializedUrlState } = setup();
               const expectedState = {
-                ...initalState,
+                ...initialState,
                 left: {
-                  ...initalState.left,
+                  ...initialState.left,
                   update: {
-                    ...initalState.left.update,
+                    ...initialState.left.update,
                     ui: true,
                   },
                 },
               };
-              const stateWithDifferentDataSource = {
-                ...initalState,
+              const stateWithDifferentDataSource: any = {
+                ...initialState,
                 left: {
-                  ...initalState.left,
+                  ...initialState.left,
                   urlState: {
-                    ...initalState.left.urlState,
+                    ...initialState.left.urlState,
                     ui: {
-                      ...initalState.left.urlState.ui,
+                      ...initialState.left.urlState!.ui,
                       showingGraph: true,
                     },
                   },
                 },
               };
 
-              reducerTester()
+              reducerTester<ExploreState>()
                 .givenReducer(exploreReducer, stateWithDifferentDataSource)
                 .whenActionIsDispatched(
                   updateLocation({
@@ -559,11 +638,11 @@ describe('Explore reducer', () => {
 
           describe('and nothing differs', () => {
             it('then it should return update ui', () => {
-              const { initalState, serializedUrlState } = setup();
-              const expectedState = { ...initalState };
+              const { initialState, serializedUrlState } = setup();
+              const expectedState = { ...initialState };
 
-              reducerTester()
-                .givenReducer(exploreReducer, initalState)
+              reducerTester<ExploreState>()
+                .givenReducer(exploreReducer, initialState)
                 .whenActionIsDispatched(
                   updateLocation({
                     query: {
